@@ -3,7 +3,8 @@ use warnings;
 
 package Test::WithSetup;
 use App::Cmd::Setup -app => {
-  plugins => [ qw(Test::XyzzyPlugin) ],
+  getopt_conf => [],
+  plugins => [ qw(=Test::XyzzyPlugin) ],
 };
 
 1;
